pub struct Create {Show 34 fields
pub bto: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub published: Option<DateTime>,
pub context: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub end_time: Option<DateTime>,
pub instrument: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub duration: Option<Duration>,
pub object_type: Property<String>,
pub id: Option<Url>,
pub attributed_to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub image: Property<Or<LinkSubtypes, Remotable<ImageSubtypes>>>,
pub content: LangContainer<Property<String>>,
pub start_time: Option<DateTime>,
pub target: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub bcc: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub replies: Property<Remotable<CollectionSubtypes>>,
pub preview: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub name: LangContainer<Property<String>>,
pub object: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub origin: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub actor: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub media_type: Option<String>,
pub to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub cc: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub url: Property<Or<Url, LinkSubtypes>>,
pub generator: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub in_reply_to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub result: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub icon: Property<Or<LinkSubtypes, Remotable<ImageSubtypes>>>,
pub audience: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub tag: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub updated: Option<DateTime>,
pub attachment: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
pub summary: LangContainer<Property<String>>,
pub location: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>,
}Expand description
https://www.w3.org/ns/activitystreams#Create
Indicates that the Create::actor has created the Create::object.
Fields
bto: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#bto
Identifies an Object that is part of the private primary audience of this Object.
published: Option<DateTime>https://www.w3.org/ns/activitystreams#published
The date and time at which the object was published
context: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#context
Identifies the context within which the object exists or an activity was performed. The notion of “context” used is intentionally vague. The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose. An example could be all activities relating to a common project or event.
end_time: Option<DateTime>https://www.w3.org/ns/activitystreams#endTime
The date and time describing the actual or expected ending time of the object. When used with an Activity object, for instance, the Activity::end_time property specifies the moment the activity concluded or is expected to conclude.
instrument: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#instrument
Identifies one or more objects used (or to be used) in the completion of an Activity.
duration: Option<Duration>https://www.w3.org/ns/activitystreams#duration
When the object describes a time-bound resource,
such as an audio or video,
a meeting, etc, the Object::duration property indicates the object’s approximate duration.
The value must be expressed as an xsd::Duration as defined by xmlschema11-2,
section 3.3.6 (e.g. a period of 5 seconds is represented as PT5S).
object_type: Property<String>@type
Kind of ObjectSubtypes
id: Option<Url>@id
Id of Object
attributed_to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#attributedTo
Identifies one or more entities to which this object is attributed. The attributed entities might not be Actors. For instance, an object might be attributed to the completion of another activity.
image: Property<Or<LinkSubtypes, Remotable<ImageSubtypes>>>https://www.w3.org/ns/activitystreams#image
Indicates an entity that describes an image for this object. Unlike the icon property, there are no aspect ratio or display size limitations assumed.
content: LangContainer<Property<String>>https://www.w3.org/ns/activitystreams#content
The content or textual representation of the Object encoded as a JSON string. By default, the value of content is HTML. The Object::media_type property can be used in the object to indicate a different content type. The content may be expressed using multiple language-tagged values.
start_time: Option<DateTime>https://www.w3.org/ns/activitystreams#startTime
The date and time describing the actual or expected starting time of the object. When used with an Activity object, for instance, the Activity::start_time property specifies the moment the activity began or is scheduled to begin.
target: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#target
Describes the indirect object, or target, of the activity.
The precise meaning of the target is largely dependent on the type of action being described but will often be the object of the English preposition “to”.
For instance, in the activity John added a movie to his wishlist, the target of the activity is John’s wishlist.
An activity can have more than one target.
bcc: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#bcc
Identifies one or more Objects that are part of the private secondary audience of this Object.
replies: Property<Remotable<CollectionSubtypes>>https://www.w3.org/ns/activitystreams#replies
Identifies a CollectionSubtypes containing objects considered to be responses to this object.
preview: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#preview
Identifies an entity that provides a preview of this object.
name: LangContainer<Property<String>>https://www.w3.org/ns/activitystreams#name
A simple, human-readable, plain-text name for the object. HTML markup must not be included. The name may be expressed using multiple language-tagged values.
object: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#object
Describes the direct object of the activity.
For instance, in the activity John added a movie to his wishlist, the object of the activity is the movie added.
origin: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#origin
Describes an indirect object of the activity from which the activity is directed. The precise meaning of the origin is the object of the English preposition “from”. For instance, in the activity “John moved an item to List B from List A”, the origin of the activity is “List A”.
actor: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#actor
Describes one or more entities that either performed or are expected to perform the activity. Any single activity can have multiple Activity::actors. The Activity::actor may be specified using an indirect Link.
media_type: Option<String>https://www.w3.org/ns/activitystreams#mediaType
Identifies the MIME media type of the value of the Object::content property.
If not specified, the Object::content property is assumed to contain text/html content.
to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#to
Identifies an entity considered to be part of the public primary audience of an Object
cc: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#cc
Identifies an Object that is part of the public secondary audience of this Object.
url: Property<Or<Url, LinkSubtypes>>https://www.w3.org/ns/activitystreams#url
Identifies one or more links to representations of the object
generator: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#generator
Identifies the entity (e.g. an application) that generated the object.
in_reply_to: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#inReplyTo
Indicates one or more entities for which this object is considered a response.
result: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#result
Describes the result of the activity. For instance, if a particular action results in the creation of a new resource, the result property can be used to describe that new resource.
icon: Property<Or<LinkSubtypes, Remotable<ImageSubtypes>>>https://www.w3.org/ns/activitystreams#icon
Indicates an entity that describes an icon for this object. The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.
audience: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#audience
Identifies one or more entities that represent the total population of entities for which the object can considered to be relevant.
tag: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#tag
One or more “tags” that have been associated with an objects. A tag can be any kind of Object. The key difference between Object::attachment and Object::tag is that the former implies association by inclusion, while the latter implies associated by reference.
updated: Option<DateTime>https://www.w3.org/ns/activitystreams#updated
The date and time at which the object was updated
attachment: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#attributedTo
Identifies a resource attached or related to an object that potentially requires special handling. The intent is to provide a model that is at least semantically similar to attachments in email.
summary: LangContainer<Property<String>>https://www.w3.org/ns/activitystreams#summary
A natural language summarization of the object encoded as HTML. Multiple language tagged summaries may be provided.
location: Property<Or<LinkSubtypes, Remotable<ObjectSubtypes>>>https://www.w3.org/ns/activitystreams#location
Indicates one or more physical or logical locations associated with the object.
Implementations
Sourceimpl Create
impl Create
Sourcepub fn builder() -> CreateBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> CreateBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building Create.
On the builder, call .bto(...), .published(...), .context(...), .end_time(...), .instrument(...), .duration(...), .object_type(...), .id(...), .attributed_to(...), .image(...), .content(...), .start_time(...), .target(...), .bcc(...), .replies(...), .preview(...), .name(...), .object(...), .origin(...), .actor(...), .media_type(...), .to(...), .cc(...), .url(...), .generator(...), .in_reply_to(...), .result(...), .icon(...), .audience(...), .tag(...), .updated(...), .attachment(...), .summary(...), .location(...) to set the values of the fields.
Finally, call .build() to create the instance of Create.